@@ -93,7 +93,7 @@ class Exceptions:
 
 class DevOpsGuruClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html)
     """
 
@@ -111,7 +111,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Adds a notification channel to DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.add_notification_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.add_notification_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#add_notification_channel)
         """
 
@@ -119,7 +119,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#can_paginate)
         """
 
@@ -128,19 +128,19 @@ class DevOpsGuruClient(BaseClient):
         Returns the number of open reactive insights, the number of open proactive
         insights, and the number of metrics analyzed in your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_health)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_account_health)
         """
 
     def describe_account_overview(
-        self, *, FromTime: Union[datetime, str], ToTime: Union[datetime, str] = None
+        self, *, FromTime: Union[datetime, str], ToTime: Union[datetime, str] = ...
     ) -> DescribeAccountOverviewResponseTypeDef:
         """
         For the time range passed in, returns the number of open reactive insight that
         were created, the number of open proactive insights that were created, and the
         Mean Time to Recover (MTTR) for all closed reactive insights.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_overview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_overview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_account_overview)
         """
 
@@ -148,16 +148,16 @@ class DevOpsGuruClient(BaseClient):
         """
         Returns details about an anomaly that you specify using its ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.describe_anomaly)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.describe_anomaly)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_anomaly)
         """
 
-    def describe_feedback(self, *, InsightId: str = None) -> DescribeFeedbackResponseTypeDef:
+    def describe_feedback(self, *, InsightId: str = ...) -> DescribeFeedbackResponseTypeDef:
         """
         Returns the most recent feedback submitted in the current AWS account and
         Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.describe_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.describe_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_feedback)
         """
 
@@ -165,19 +165,19 @@ class DevOpsGuruClient(BaseClient):
         """
         Returns details about an insight that you specify using its ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.describe_insight)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.describe_insight)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_insight)
         """
 
     def describe_resource_collection_health(
-        self, *, ResourceCollectionType: ResourceCollectionTypeType, NextToken: str = None
+        self, *, ResourceCollectionType: ResourceCollectionTypeType, NextToken: str = ...
     ) -> DescribeResourceCollectionHealthResponseTypeDef:
         """
         Returns the number of open proactive insights, open reactive insights, and the
         Mean Time to Recover (MTTR) for all closed insights in resource collections in
         your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.describe_resource_collection_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.describe_resource_collection_health)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_resource_collection_health)
         """
 
@@ -185,40 +185,40 @@ class DevOpsGuruClient(BaseClient):
         """
         Returns the integration status of services that are integrated with DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.describe_service_integration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.describe_service_integration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_service_integration)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#generate_presigned_url)
         """
 
-    def get_cost_estimation(self, *, NextToken: str = None) -> GetCostEstimationResponseTypeDef:
+    def get_cost_estimation(self, *, NextToken: str = ...) -> GetCostEstimationResponseTypeDef:
         """
         Returns an estimate of the monthly cost for DevOps Guru to analyze your AWS
         resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.get_cost_estimation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.get_cost_estimation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#get_cost_estimation)
         """
 
     def get_resource_collection(
-        self, *, ResourceCollectionType: ResourceCollectionTypeType, NextToken: str = None
+        self, *, ResourceCollectionType: ResourceCollectionTypeType, NextToken: str = ...
     ) -> GetResourceCollectionResponseTypeDef:
         """
         Returns lists AWS resources that are of the specified resource collection type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.get_resource_collection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.get_resource_collection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#get_resource_collection)
         """
 
@@ -226,26 +226,26 @@ class DevOpsGuruClient(BaseClient):
         self,
         *,
         InsightId: str,
-        StartTimeRange: "StartTimeRangeTypeDef" = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        StartTimeRange: "StartTimeRangeTypeDef" = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListAnomaliesForInsightResponseTypeDef:
         """
         Returns a list of the anomalies that belong to an insight that you specify using
         its ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.list_anomalies_for_insight)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.list_anomalies_for_insight)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_anomalies_for_insight)
         """
 
     def list_events(
-        self, *, Filters: "ListEventsFiltersTypeDef", MaxResults: int = None, NextToken: str = None
+        self, *, Filters: "ListEventsFiltersTypeDef", MaxResults: int = ..., NextToken: str = ...
     ) -> ListEventsResponseTypeDef:
         """
         Returns a list of the events emitted by the resources that are evaluated by
         DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.list_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.list_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_events)
         """
 
@@ -253,41 +253,41 @@ class DevOpsGuruClient(BaseClient):
         self,
         *,
         StatusFilter: "ListInsightsStatusFilterTypeDef",
-        MaxResults: int = None,
-        NextToken: str = None
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListInsightsResponseTypeDef:
         """
         Returns a list of insights in your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.list_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.list_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_insights)
         """
 
     def list_notification_channels(
-        self, *, NextToken: str = None
+        self, *, NextToken: str = ...
     ) -> ListNotificationChannelsResponseTypeDef:
         """
         Returns a list of notification channels configured for DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.list_notification_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.list_notification_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_notification_channels)
         """
 
     def list_recommendations(
-        self, *, InsightId: str, NextToken: str = None, Locale: LocaleType = None
+        self, *, InsightId: str, NextToken: str = ..., Locale: LocaleType = ...
     ) -> ListRecommendationsResponseTypeDef:
         """
         Returns a list of a specified insight's recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.list_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.list_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_recommendations)
         """
 
-    def put_feedback(self, *, InsightFeedback: "InsightFeedbackTypeDef" = None) -> Dict[str, Any]:
+    def put_feedback(self, *, InsightFeedback: "InsightFeedbackTypeDef" = ...) -> Dict[str, Any]:
         """
         Collects customer feedback about the specified insight.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.put_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.put_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#put_feedback)
         """
 
@@ -295,7 +295,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Removes a notification channel from DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.remove_notification_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.remove_notification_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#remove_notification_channel)
         """
 
@@ -304,14 +304,14 @@ class DevOpsGuruClient(BaseClient):
         *,
         StartTimeRange: "StartTimeRangeTypeDef",
         Type: InsightTypeType,
-        Filters: "SearchInsightsFiltersTypeDef" = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        Filters: "SearchInsightsFiltersTypeDef" = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> SearchInsightsResponseTypeDef:
         """
         Returns a list of insights in your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.search_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.search_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#search_insights)
         """
 
@@ -319,13 +319,13 @@ class DevOpsGuruClient(BaseClient):
         self,
         *,
         ResourceCollection: "CostEstimationResourceCollectionFilterTypeDef",
-        ClientToken: str = None
+        ClientToken: str = ...
     ) -> Dict[str, Any]:
         """
         Starts the creation of an estimate of the monthly cost to analyze your AWS
         resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.start_cost_estimation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.start_cost_estimation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#start_cost_estimation)
         """
 
@@ -338,7 +338,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Updates the collection of resources that DevOps Guru analyzes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.update_resource_collection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.update_resource_collection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#update_resource_collection)
         """
 
@@ -349,7 +349,7 @@ class DevOpsGuruClient(BaseClient):
         Enables or disables integration with a service that can be integrated with
         DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Client.update_service_integration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Client.update_service_integration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#update_service_integration)
         """
 
@@ -358,7 +358,7 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["describe_resource_collection_health"]
     ) -> DescribeResourceCollectionHealthPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#describeresourcecollectionhealthpaginator)
         """
 
@@ -367,7 +367,7 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["get_cost_estimation"]
     ) -> GetCostEstimationPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#getcostestimationpaginator)
         """
 
@@ -376,7 +376,7 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["get_resource_collection"]
     ) -> GetResourceCollectionPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#getresourcecollectionpaginator)
         """
 
@@ -385,21 +385,21 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["list_anomalies_for_insight"]
     ) -> ListAnomaliesForInsightPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listanomaliesforinsightpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_events"]) -> ListEventsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listeventspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_insights"]) -> ListInsightsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listinsightspaginator)
         """
 
@@ -408,7 +408,7 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["list_notification_channels"]
     ) -> ListNotificationChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listnotificationchannelspaginator)
         """
 
@@ -417,13 +417,13 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["list_recommendations"]
     ) -> ListRecommendationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listrecommendationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["search_insights"]) -> SearchInsightsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#searchinsightspaginator)
         """
