@@ -82,7 +82,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class DescribeResourceCollectionHealthPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#describeresourcecollectionhealthpaginator)
     """
 
@@ -90,32 +90,32 @@ class DescribeResourceCollectionHealthPaginator(Boto3Paginator):
         self,
         *,
         ResourceCollectionType: ResourceCollectionTypeType,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeResourceCollectionHealthResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#describeresourcecollectionhealthpaginator)
         """
 
 
 class GetCostEstimationPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#getcostestimationpaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetCostEstimationResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#getcostestimationpaginator)
         """
 
 
 class GetResourceCollectionPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#getresourcecollectionpaginator)
     """
 
@@ -123,17 +123,17 @@ class GetResourceCollectionPaginator(Boto3Paginator):
         self,
         *,
         ResourceCollectionType: ResourceCollectionTypeType,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetResourceCollectionResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#getresourcecollectionpaginator)
         """
 
 
 class ListAnomaliesForInsightPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listanomaliesforinsightpaginator)
     """
 
@@ -141,36 +141,33 @@ class ListAnomaliesForInsightPaginator(Boto3Paginator):
         self,
         *,
         InsightId: str,
-        StartTimeRange: "StartTimeRangeTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        StartTimeRange: "StartTimeRangeTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAnomaliesForInsightResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listanomaliesforinsightpaginator)
         """
 
 
 class ListEventsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listeventspaginator)
     """
 
     def paginate(
-        self,
-        *,
-        Filters: "ListEventsFiltersTypeDef",
-        PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, Filters: "ListEventsFiltersTypeDef", PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEventsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listeventspaginator)
         """
 
 
 class ListInsightsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listinsightspaginator)
     """
 
@@ -178,32 +175,32 @@ class ListInsightsPaginator(Boto3Paginator):
         self,
         *,
         StatusFilter: "ListInsightsStatusFilterTypeDef",
-        PaginationConfig: PaginatorConfigTypeDef = None
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListInsightsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listinsightspaginator)
         """
 
 
 class ListNotificationChannelsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listnotificationchannelspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListNotificationChannelsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listnotificationchannelspaginator)
         """
 
 
 class ListRecommendationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listrecommendationspaginator)
     """
 
@@ -211,18 +208,18 @@ class ListRecommendationsPaginator(Boto3Paginator):
         self,
         *,
         InsightId: str,
-        Locale: LocaleType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        Locale: LocaleType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRecommendationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listrecommendationspaginator)
         """
 
 
 class SearchInsightsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#searchinsightspaginator)
     """
 
@@ -231,10 +228,10 @@ class SearchInsightsPaginator(Boto3Paginator):
         *,
         StartTimeRange: "StartTimeRangeTypeDef",
         Type: InsightTypeType,
-        Filters: "SearchInsightsFiltersTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        Filters: "SearchInsightsFiltersTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[SearchInsightsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#searchinsightspaginator)
         """
